==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_fields/PERCENTAGEWINDOW.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="OK" type="{http://schemas.datastream.net/MP_fields}LONG_0_100_Type" minOccurs="0"/>
 *         &lt;element name="NEAR" type="{http://schemas.datastream.net/MP_fields}LONG_0_100_Type" minOccurs="0"/>
 *         &lt;element name="RELEASE" type="{http://schemas.datastream.net/MP_fields}LONG_0_100_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "ok",
    "near",
    "release"
})
@XmlRootElement(name = "PERCENTAGEWINDOW")
public class PERCENTAGEWINDOW {

    @XmlElement(name = "OK")
    @XmlSchemaType(name = "long")
    protected Integer ok;
    @XmlElement(name = "NEAR")
    @XmlSchemaType(name = "long")
    protected Integer near;
    @XmlElement(name = "RELEASE")
    @XmlSchemaType(name = "long")
    protected Integer release;

    /**
     * Obtient la valeur de la propriété ok.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getOK() {
        return ok;
    }

    /**
     * Définit la valeur de la propriété ok.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setOK(Integer value) {
        this.ok = value;
    }

    /**
     * Obtient la valeur de la propriété near.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getNEAR() {
        return near;
    }

    /**
     * Définit la valeur de la propriété near.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setNEAR(Integer value) {
        this.near = value;
    }

    /**
     * Obtient la valeur de la propriété release.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getRELEASE() {
        return release;
    }

    /**
     * Définit la valeur de la propriété release.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setRELEASE(Integer value) {
        this.release = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/PERCENTAGEWINDOW.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="OK" type="{http://schemas.datastream.net/MP_fields}LONG_0_100_Type" minOccurs="0"/>
 *         &lt;element name="NEAR" type="{http://schemas.datastream.net/MP_fields}LONG_0_100_Type" minOccurs="0"/>
 *         &lt;element name="RELEASE" type="{http://schemas.datastream.net/MP_fields}LONG_0_100_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "ok",
    "near",
    "release"
})
@XmlRootElement(name = "PERCENTAGEWINDOW")
public class PERCENTAGEWINDOW {

    @XmlElement(name = "OK")
    @XmlSchemaType(name = "long")
    protected Integer ok;
    @XmlElement(name = "NEAR")
    @XmlSchemaType(name = "long")
    protected Integer near;
    @XmlElement(name = "RELEASE")
    @XmlSchemaType(name = "long")
    protected Integer release;

    /**
     * Gets the value of the ok property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getOK() {
        return ok;
    }

    /**
     * Sets the value of the ok property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setOK(Integer value) {
        this.ok = value;
    }

    /**
     * Gets the value of the near property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getNEAR() {
        return near;
    }

    /**
     * Sets the value of the near property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setNEAR(Integer value) {
        this.near = value;
    }

    /**
     * Gets the value of the release property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getRELEASE() {
        return release;
    }

    /**
     * Sets the value of the release property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setRELEASE(Integer value) {
        this.release = value;
    }

}
